import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-MoleculeCollapsible';
var CONTENT_CLASS = BASE_CLASS + "-content";
var CONTAINER_BUTTON_CLASS = BASE_CLASS + "-container";
var COLLAPSED_CLASS = 'is-collapsed';
var BUTTON_CLASS = BASE_CLASS + "-btn";
var BUTTON_CONTENT_CLASS = BUTTON_CLASS + "-content";
var ICON_CLASS = BASE_CLASS + "-icon";
var MIN_HEIGHT = 100; // px

var MoleculeCollapsible = function MoleculeCollapsible(_ref) {
  var _cx, _cx2, _cx3, _cx4;

  var onClose = _ref.onClose,
      onOpen = _ref.onOpen,
      children = _ref.children,
      height = _ref.height,
      icon = _ref.icon,
      showText = _ref.showText,
      hideText = _ref.hideText,
      withGradient = _ref.withGradient,
      withTransition = _ref.withTransition;
  var childrenContainer = useRef();

  var _useState = useState(true),
      _useState2 = _slicedToArray(_useState, 2),
      collapsed = _useState2[0],
      setCollapsed = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      showButton = _useState4[0],
      setShowButton = _useState4[1];

  var _useState5 = useState(MIN_HEIGHT),
      _useState6 = _slicedToArray(_useState5, 2),
      maxHeight = _useState6[0],
      setMaxHeight = _useState6[1];

  var toggleCollapse = function toggleCollapse() {
    if (showButton) {
      setCollapsed(!collapsed);
      collapsed && onOpen() || onClose();
    }
  };

  useEffect(function () {
    var offsetHeight = childrenContainer.current.offsetHeight;
    setShowButton(offsetHeight >= height);
    setMaxHeight(offsetHeight);
  }, [height]);
  var wrapperClassName = cx("" + BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--withGradient"] = withGradient, _cx[COLLAPSED_CLASS] = collapsed, _cx));
  var iconClassName = cx("" + ICON_CLASS, (_cx2 = {}, _cx2[COLLAPSED_CLASS] = collapsed, _cx2));
  var containerClassName = cx("" + CONTAINER_BUTTON_CLASS, (_cx3 = {}, _cx3[CONTAINER_BUTTON_CLASS + "--withGradient"] = withGradient, _cx3[COLLAPSED_CLASS] = collapsed, _cx3));
  var contentClassName = cx("" + CONTENT_CLASS, (_cx4 = {}, _cx4[CONTENT_CLASS + "--withTransition"] = withTransition, _cx4));
  var containerHeight = showButton && collapsed ? height + "px" : maxHeight + "px";
  return React.createElement("div", {
    className: wrapperClassName
  }, React.createElement("div", {
    className: contentClassName,
    style: {
      maxHeight: "" + containerHeight
    }
  }, React.createElement("div", {
    ref: childrenContainer
  }, children)), showButton && React.createElement("div", {
    className: containerClassName
  }, React.createElement("button", {
    type: "button",
    className: BUTTON_CLASS,
    onClick: toggleCollapse
  }, React.createElement("span", {
    className: BUTTON_CONTENT_CLASS,
    tabIndex: "-1"
  }, collapsed ? showText : hideText, React.createElement("span", {
    className: iconClassName
  }, icon)))));
};

MoleculeCollapsible.displayName = 'MoleculeCollapsible';
MoleculeCollapsible.defaultProps = {
  height: MIN_HEIGHT,
  withGradient: true,
  withTransition: true,
  onOpen: function onOpen() {},
  onClose: function onClose() {}
};
export default MoleculeCollapsible;